package HSPC::Plugin::API::Common;

use strict;

$ENV{MOD_PERL} = 0;

use Data::Dumper;
use HSPC::System;
use HSPC::Config;
use HSPC::Logger;
use HSPC::Localization;
use HSPC::MT::Core::Constants;
use HSPC::MT::Abstract;
use HSPC::MT::PluginConfig;
use HSPC::MT::PluginTools;

use base qw(Exporter);
use vars qw(@EXPORT_OK);

@EXPORT_OK = qw(
	prepare_account_from_soap
	prepare_hash_from_soap
	APIResult
	APIResultErrors
);

sub new
{
	$ENV{system_obj} = HSPC::System->new();

	HSPC::Logger->init();
	HSPC::Localization::load_all_languages();

	return bless {} => shift;
}

sub init_plugin_argparams
{
	my $me = shift;
	my $params = shift;

	HSPC::MT::PluginTools->init_plugin_argparams(
		plugin_argparams => $params,
	);
}

sub get_plugins($$)
{
	my $me = shift;
	my $plugin_type = shift;

	my $templates = HSPC::MT::PluginConfig->find_templates(
		plugin_type			=> $plugin_type,
		vendor_id			=> 1,
		force_permission	=> 1,
	);
	return APIResult($templates);
}

sub get_plugin_templates($$$)
{
	my $me = shift;
	my $plugin_type = shift;
	my $template_id = shift;

	my $plugin_config = HSPC::MT::PluginConfig::PP->new();
	$plugin_config->vendor_id(SW_HSP_ID);
	$plugin_config->plugin_type($plugin_type);
	$plugin_config->template_id($template_id);

	my $pr_template = $plugin_config->find_presentation_template();
	my $mt_template = $plugin_config->find_mt_template();

	eval("require $pr_template");
	eval("require $mt_template");

	return {
		"pr_template" => $pr_template,
		"mt_template" => $mt_template,
	};
}

sub get_help_page($$)
{
	my $me = shift;
	my $args = shift;

	my $templates = HSPC::Plugin::API::Common->get_plugin_templates($args->{plugin_type}, $args->{template_id});

	my $page = $templates->{pr_template}->get_help_page(
		action => $args->{action},
		language => $args->{language},
		customer_view => $args->{customer_view},
	);

	return APIResult(HSPC::Plugin::SOAP::Struct::HelpPageResult->new(page => $page));
}

sub prepare_account_from_soap
{
	my $account = shift;
	my $result = {};

	foreach my $contact_type qw(admin billing technical)
	{
		foreach my $param (keys %{$account->{$contact_type}})
		{
			$result->{$contact_type . "_" . $param} = $account->{$contact_type}->{$param};
		}
	}

	foreach my $address_param qw(address_address1 address_address2 address_city address_country address_state address_zip address_phone address_fax address_mobile)
	{
		$result->{$address_param} = $result->{"admin_" . $address_param};
	}

	return $result;
}

sub prepare_hash_from_soap
{
	my $hash = shift;
	my $default = shift;
	my $strip_slashes = shift;
	my $result;

	return $default if (ref($hash) eq "ARRAY" && 0 == scalar((@{$hash})));

	if ($strip_slashes)
	{
		use HTML::Entities;
		foreach my $key (keys %{$hash})
		{
			decode_entities($hash->{$key});
			$hash->{$key} =~ s/\\\"/\"/g;
			$hash->{$key} =~ s/\\\'/\'/g;
			$hash->{$key} =~ s/\\\\/\\/g;
			encode_entities($hash->{$key});
		}
	}
##	use Data::Dumper;
##	die(Dumper($hash));
	return $hash;
}

sub APIResult
{
	return HSPC::Plugin::SOAP::Struct::APIResult->new(@_);
}

sub APIResultErrors
{
	return APIResult()->errors(@_);
}

1;
